Crate dioxus_gestures

Crate dioxus_gestures 

Drag, Pinch, and Hover gestures for dioxus components.

Demo: https://wakefullynx.dev/dioxus-gestures-demo/

Please note: This crate is in early development and may contain bugs and missing implementations. Currently only tested on the Web platform. If you are using fullstack, you must also enable the fullstack feature of dioxus-gestures.

W3C Drafts and applicable documents:

  • https://www.w3.org/TR/pointerevents/
  • https://www.w3.org/TR/2025/WD-pointerevents4-20250501/
  • https://www.w3.org/TR/2025/CRD-pointerevents3-20250501/
  • https://www.w3.org/TR/2019/REC-pointerevents2-20190404/
  • https://drafts.csswg.org/selectors/#hover-pseudo

Re-exports

pub use use_gestures::use_gestures;

Modules

state
use_gestures